<!doctype html>
<head>
  <%namespace name="macros" file="macros.mako" />

  <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
  <meta name="viewport" content="width=device-width, initial-scale=1, minimum-scale=1" />

  <title>${project.name} documentation</title>
  <meta name="description" content="" />

  <link href="https://fonts.googleapis.com/css?family=Source+Sans+Pro:400,300"
    rel="stylesheet" type="text/css">

  <style type="text/css">
<%include file="css-pygments.mako" />
<%include file="css-normalize.mako" />
<%include file="css-adoc.mako" />
<%include file="css-rst.mako" />
<%include file="css-print.mako" />
  </style>
</head>
<body>
  <div id="container">
    <div id="sidebar">
      <h2>
        <strong>${project.name}</strong>

        % if project.has_meta('version'):
          (<small>${project.get_meta('version')}</small>)
        % endif
      </h2>

      % if project.has_meta('description'):
        <p>${project.get_meta('description')}</p>
      % endif

      % if project.has_meta('author', 'author_email', 'license', 'url', 'project_urls'):
        <ul class="metadata">
          % if project.has_meta('author'):
            % if project.has_meta('author_email'):
              <li>
                <a href="mailto:${project.get_meta('author_email')}">
                  ${project.get_meta('author') | h}
                </a>
              </li>
            % else:
              <li>${project.get_meta('author') | h}</li>
            % endif
          % endif

          % if project.has_meta('maintainer'):
            % if project.has_meta('maintainer_email'):
              <li>
                <a href="mailto:${project.get_meta('maintainer_email')}">
                  ${project.get_meta('maintainer') | h}
                </a>
              </li>
            % else:
              <li>${project.get_meta('maintainer') | h}</li>
            % endif
          % endif

          % if project.has_meta('license'):
            <li>${project.get_meta('license') | h}</li>
          % endif

          % if project.has_meta('url'):
            <li><a href="${project.get_meta('url')}">Project page</a></li>
          % endif

          % if project.has_meta('project_urls'):
            % for key, value in project.get_meta('project_urls').items():
              <li><a href="${value}">${key | h}</a></li>
            % endfor
          % endif
        </ul>
      % endif

      <h2>Index</h2>

      <ul id="index">
        <li class="set">
          <h3>
            <a href="#content">Introduction</a>
          </h3>

          <ul>
            % for document in project.documents:
              <li>
                <a href="#doc-${document.name}">${document.title}</a>
              </li>
            % endfor
          </ul>
        </li>

        % for document in project.documents:
          <li class="set">
            <h3>
              <a href="#doc-${document.name}">${document.title}</a>
            </h3>
          </li>
        % endfor

        <li class="set">
          <h3>
            <a href="#api-reference">API Reference</a>
          </h3>
        </li>

        <li class="set">
          <h3>
            Filter Symbols
          </h3>

          <input id="filter" accessKey="/" placeholder="Alt+/ or Alt+Shift+/">
        </li>

        <li class="set">
          <h3 id="modules">
            <a href="#modules">Modules</a>
          </h3>

          ${macros.list_modules(project)}
        </li>

        <li class="set">
          <h3 id="functions">
            <a href="#functions">Functions</a>
          </h3>

          ${macros.list_functions(project)}
        </li>

        <li class="set">
          <h3 id="classes">
            <a href="#classes">Classes</a>
          </h3>

          ${macros.list_classes(project)}
        </li>
      </ul>
    </div>

    <article id="content">
      <section>
        ${project.doc.html}
      </section>

      % for document in project.documents:
        <section id="doc-${document.name}">
          ${document.html}
        </section>
      % endfor

      <section>
        <h1 class="section-title" id="api-reference">
          API Reference
        </h1>

        ${macros.show_modules(project)}
      </section>
    </article>

    <div class="clear"> </div>

    <footer id="footer">
      <p>
        Generated by <a href="https://github.com/saalaa/adoc">adoc</a>
      </p>

      <p>
        Designed by <a href="http://nadh.in">Kailash Nadh</a>
      </p>
    </footer>
  </div>

  <script>
    (function () {
      var input = document.getElementById('filter');
      var searchables = document.querySelectorAll('li.searchable');

      function filter_symbols () {
        var q = input.value
          .toLowerCase()
          .trim();

        searchables.forEach(function (el) {
          var fqn = el.getAttribute('data-fqn');
          var match = fqn.indexOf(q) !== -1;

          el.style.display = match ? '' : 'none';
        });
      }

      input.addEventListener('input', filter_symbols, false);
    })();
  </script>
</body>
</html>
